/*
 * SDLWindow.cpp
 *
 *  Created on: 17 déc. 2023
 *      Author: fanch
 */

#include "SDLWindow.h"
#include "common/NoteSpectrum.h"
SDLWindow::SDLWindow(int w, int h){
	m_w = w;
	m_h = h;
	m_window =  SDL_CreateWindow("Ma première application SDL2",SDL_WINDOWPOS_UNDEFINED,
			SDL_WINDOWPOS_UNDEFINED,
			w,
			h,
			SDL_WINDOW_SHOWN);
	m_renderer = SDL_CreateRenderer(m_window, -1, 0);

	m_texture = SDL_CreateTexture(m_renderer,
		SDL_PIXELFORMAT_ARGB8888, SDL_TEXTUREACCESS_STATIC, w, h);
	m_pixels = new Uint32[w*h];
}
SDLWindow::~SDLWindow(){
	delete[] m_pixels;
	SDL_DestroyTexture(m_texture);
	SDL_DestroyRenderer(m_renderer);
}

void SDLWindow::init(){
	SDL_Init(SDL_INIT_VIDEO);
}

void SDLWindow::update(){
	SDL_UpdateTexture(m_texture, NULL, m_pixels, m_w* sizeof(Uint32));
	SDL_RenderClear(m_renderer);
	SDL_RenderCopy(m_renderer, m_texture, NULL, NULL);
	SDL_RenderPresent(m_renderer);
}


void SDLWindow::set_value(float* value, int size, float ratio){
	memset(m_pixels, 0, sizeof(*m_pixels) * m_w*m_h );
	for(int j=0; j<m_w; j+=2){
		int h = ((value[j]*ratio) + m_h/2);
		if(h<0) h=0;
		if(h>=m_h) h=m_h-1;
		m_pixels[h*m_w+j] = 0xFFFFFF00;
		m_pixels[h*m_w+j+1] = 0xFFFFFF00;
	}
	update();
}

void SDLWindow::set_value(const NoteValue* value, float ratio){
	memset(m_pixels, 0, sizeof(*m_pixels) * m_w*m_h );
	const int w = m_w/256;

	for(int i=0; i<128; i++){
		for(int j=i*w; j<i*w+w; j++){
			int h = ((value[i].velocity*0.5) + m_h/2);
			if(h<0) h=0;
			if(h>=m_h) h=m_h-1;
			uint32_t color =((value[i].precision) * 256 * 256) + 128*256 ;

			for(int k=m_h-h; k<m_h-10; k++){
				m_pixels[k*m_w+j] = color;
			}
		}

	}
	update();
}
